@@ -465,7 +465,7 @@ rT2 <- function(n, df1, df2, delta2) {
 #' @param drag the 'drag' term, \eqn{c_0/R}{c0/R}. defaults to 0. It is assumed
 #'        that \code{drag} has been annualized, \emph{i.e.} is given in the
 #'        same units as \code{x} and \code{q}.
-#' @param log logical; if TRUE, probabilities p are given as \eqn{\mbox{log}(p)}{log(p)}.
+#' @param log logical; if TRUE, densities \eqn{f} are given as \eqn{\mbox{log}(f)}{log(f)}.
 #' @param ... arguments passed on to the respective Hotelling \eqn{T^2} functions.
 #' @keywords distribution 
 #' @return \code{dsropt} gives the density, \code{psropt} gives the distribution function,
@@ -473,9 +473,7 @@ rT2 <- function(n, df1, df2, delta2) {
 #'
 #' Invalid arguments will result in return value \code{NaN} with a warning.
 #' @rdname dsropt
-#' @aliases psropt
-#' @aliases qsropt 
-#' @aliases rsropt
+#' @aliases psropt qsropt rsropt
 #' @seealso F-distribution functions, \code{\link{df}, \link{pf}, \link{qf}, \link{rf}}, 
 #' Sharpe ratio distribution, \code{\link{dsr}, \link{psr}, \link{qsr}, \link{rsr}}.
 #' @export 
@@ -594,7 +592,7 @@ rsropt <- function(n, df1, df2, zeta.s, ope, drag = 0, ...) {
 # 'confidence distributions'
 
 # lambda prime
-# plambdap, qlambdap#FOLDUP
+# plambdap, qlambdap, rlambdap#FOLDUP
 #' @title The lambda-prime distribution.
 #'
 #' @description 
@@ -626,8 +624,12 @@ rsropt <- function(n, df1, df2, zeta.s, ope, drag = 0, ...) {
 #'
 #' qlambdap(p, df, tstat, lower.tail = TRUE, log.p = FALSE)
 #'
+#' rlambdap(n, df, tstat)
+#'
 #' @param q vector of quantiles.
 #' @param p vector of probabilities.
+#' @param n number of observations. If 'length(n) > 1', the length is
+#' taken to be the number required.
 #' @param df the degrees of freedom of the t-statistic.
 #' @param tstat the observed (non-central) t-statistic.
 #' @param log.p logical; if TRUE, probabilities p are given as \eqn{\mbox{log}(p)}{log(p)}.
@@ -641,9 +643,7 @@ rsropt <- function(n, df1, df2, zeta.s, ope, drag = 0, ...) {
 #' \code{qlambdap} gives the quantile function, and \code{rlambdap} generates random deviates.
 #'
 #' Invalid arguments will result in return value \code{NaN} with a warning.
-#' @aliases plambdap
-#' @aliases qlambdap 
-#' @aliases rlambdap
+#' @aliases plambdap qlambdap rlambdap
 #' @seealso t-distribution functions, \code{\link{dt},\link{pt},\link{qt},\link{rt}}
 #' @export 
 #' @template etc
@@ -678,6 +678,8 @@ rsropt <- function(n, df1, df2, zeta.s, ope, drag = 0, ...) {
 #' qv <- qlambdap(c(0.1,0.2),c(128,253),2)
 #' qv <- qlambdap(c(0.1,0.2),c(128,253),c(2,4))
 #' qv <- qlambdap(c(0.1,0.2),c(128,253),c(2,4,8,16))
+#' # random generation
+#' rv <- rlambdap(1000,252,2)
 #'
 plambdap <- function(q,df,tstat,lower.tail=TRUE,log.p=FALSE) {
 	# this is just a silly wrapper on pt
@@ -731,6 +733,10 @@ plambdap <- function(q,df,tstat,lower.tail=TRUE,log.p=FALSE) {
 qlambdap <- Vectorize(.qlambdap, 
 											vectorize.args = c("p","df","tstat"),
 											SIMPLIFY = TRUE)
+#' @export 
+rlambdap <- function(n, df, tstat) {
+	rvs <- rnorm(n) + tstat * sqrt(rchisq(n, df=df) / df)
+}
 #UNFOLD
 
 # co-SR^*
